==> maven_3.5.4.orig.tar.xz: maven-maven-3.5.4/maven-core/src/main/java/org/apache/maven/classrealm/ArtifactClassRealmConstituent.java <==
package org.apache.maven.classrealm;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.io.File;

import org.eclipse.aether.artifact.Artifact;

/**
 * @author Benjamin Bentmann
 */
class ArtifactClassRealmConstituent
    implements ClassRealmConstituent
{

    private final Artifact artifact;

    ArtifactClassRealmConstituent( Artifact artifact )
    {
        this.artifact = artifact;
    }

    public String getGroupId()
    {
        return artifact.getGroupId();
    }

    public String getArtifactId()
    {
        return artifact.getArtifactId();
    }

    public String getType()
    {
        return artifact.getExtension();
    }

    public String getClassifier()
    {
        return artifact.getClassifier();
    }

    public String getVersion()
    {
        return artifact.getBaseVersion();
    }

    public File getFile()
    {
        return artifact.getFile();
    }

    @Override
    public String toString()
    {
        return artifact.toString();
    }

}

==> maven_3.9.9.orig.tar.xz: maven-maven-3.9.9/maven-core/src/main/java/org/apache/maven/classrealm/ArtifactClassRealmConstituent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.classrealm;

import java.io.File;

import org.eclipse.aether.artifact.Artifact;

/**
 * @author Benjamin Bentmann
 */
class ArtifactClassRealmConstituent implements ClassRealmConstituent {

    private final Artifact artifact;

    ArtifactClassRealmConstituent(Artifact artifact) {
        this.artifact = artifact;
    }

    public String getGroupId() {
        return artifact.getGroupId();
    }

    public String getArtifactId() {
        return artifact.getArtifactId();
    }

    public String getType() {
        return artifact.getExtension();
    }

    public String getClassifier() {
        return artifact.getClassifier();
    }

    public String getVersion() {
        return artifact.getBaseVersion();
    }

    public File getFile() {
        return artifact.getFile();
    }

    @Override
    public String toString() {
        return artifact.toString();
    }
}
